@@ -1,7 +1,7 @@
 /*! ========================================================================
 ** Extended Template and Library
 ** NULL Mutex Abstraction Class Implementation
-** $Id: _mutex_null.h 334 2007-03-16 00:37:48Z dooglus $
+** $Id$
 **
 ** Copyright (c) 2002 Robert B. Quattlebaum Jr.
 **
@@ -54,7 +54,7 @@ public:
 	class lock
 	{
 	public:
-		lock(mutex_null &x) { }
+		lock(mutex_null &/*x*/) { }
 	};
 
 	void lock_mutex(){}
