@@ -10,14 +10,10 @@
 # define ETL_NAMESPACE 			etl
 #endif
 
-#if defined(WORDS_BIGENDIAN) && !defined(ETL_BIGENDIAN)
-#define ETL_BIGENDIAN
-#endif
-
 #ifdef	WIN32
-#define ETL_DIRECTORY_SEPERATOR		'\\'
+#define ETL_DIRECTORY_SEPARATOR		'\\'
 #else
-#define ETL_DIRECTORY_SEPERATOR		'/'
+#define ETL_DIRECTORY_SEPARATOR		'/'
 #endif
 
 #ifndef ETL_FLAG_NONAMESPACE
